@@ -12,7 +12,7 @@ from textblob import TextBlob
 class process_text:
 
     def __init__(self):
-        self.__version__ = "2.6.0"
+        self.__version__ = "3.1.0"
         self.path = r".\\TextPreprocessing"
         self.abbreviations = {
             "€" : "euro",
@@ -350,7 +350,7 @@ class process_text:
         return re.sub(r'([a-z0-9+._-]+@[a-z0-9+._-]+\.[a-z0-9+_-]+)',"", text)
     
     def clear_web_url(self, text):
-        return re.sub(r'(http|https|ftp|ssh)://([\w_-]+(?:(?:\.[\w_-]+)+))([\w.,@?^=%&:/~+#-]*[\w@?^=%&/~+#-])?', '' , text)
+        return re.sub(r"(^((ftp|http|https):\/\/)?(www.)?(?!.*(ftp|http|https|www.))[a-zA-Z0-9_-]+(\.[a-zA-Z]+)+((\/)[\w#]+)*(\/\w+\?[a-zA-Z0-9_]+=\w+(&[a-zA-Z0-9_]+=\w+)*)?$)+", '' , text)
     
     def clear_html_tags(self, text):
         return BeautifulSoup(text, 'lxml').get_text().strip()
